@@ -91,7 +91,7 @@ class CLOUDXNS:
         return self.http.get(f'record/{domain_id}', params=params)
 
 
-    def record_add(self, domain_id, host_name, value, record_type='A', mx=None, ttl=600, line_id=1):
+    def record_add(self, domain_id, name, value, type='A', mx=None, ttl=60, line_id=1):
         """
         功能 添加解析记录
         HTTP 请求方式 POST
@@ -107,15 +107,15 @@ class CLOUDXNS:
                 line_id Integer 线路id,(通过 API 获得记录线路 id)
             :return: String
         """
-        if record_type not in ["A", "CNAME", "NS", "MX", "TXT", "AAAA", "LINK", "AX",
+        if type not in ["A", "CNAME", "NS", "MX", "TXT", "AAAA", "LINK", "AX",
                                "CNAMEX", "SRV", "DR301X", "DR302X", "DRHIDX"]:
             raise Exception("Invalid record type")
 
         data = {
             "domain_id": domain_id,
-            "host": host_name,
+            "host": name,
             "value": value,
-            "type": record_type,
+            "type": type,
             "ttl": ttl,
             "line_id": line_id
         }
@@ -181,3 +181,6 @@ class CLOUDXNS:
         :return: String
         """
         return self.http.get('type')
+
+
+
